# -*- coding: utf-8 -*-
"""
Created on Fri Mar 12 16:15:47 2021

@author: RefaelWhyte
"""
import chronoptics.tof as tof
import time
import numpy as np

serial = "202001a"
nframes = 25

proc_config = tof.ProcessingConfig()
proc_config.setTemporalEnabled(True)
proc_config.setMedianEnabled(True)
proc_config.setPhaseUnwrappingEnabled(True)
proc_config.setPhaseUnwrappingMaxOffset(np.pi / 2)

cam = tof.KeaCamera(proc_config, serial)

config = cam.getCameraConfig()
config.reset()

config.setModulationFrequency(0, 80.0)
config.setPhaseShifts(0, [0.0, 0.25, 0.375, 0.625])
config.setIntegrationTime(0, [300, 300, 300, 300])
config.setDutyCycle(0, 0.4)
config.setFlip(0, True)

config.addFrame()
config.setModulationFrequency(1, 100.0)
config.setPhaseShifts(1, [0.0, 0.25, 0.375, 0.625])
config.setIntegrationTime(1, [300, 300, 300, 300])
config.setDutyCycle(1, 0.4)
config.setFlip(1, True)

cam.setCameraConfig(config)

writer = tof.createCsfWriterCamera("rgbd.csf", cam)

stream_list = cam.getStreamList()

# Start RGB-D streaming.
tof.selectStreams(
    cam, [tof.FrameType.BGR, tof.FrameType.RADIAL, tof.FrameType.INTENSITY]
)

cam.start()

time.sleep(2)

for n in range(0, nframes):
    frames = cam.getFrames()

    for frame in frames:
        writer.writeFrame(frame)

    del frames

del cam
del writer
